==> infima_client-0.186.0-py3-none-any.whl: infima_client/api/cohort_service/cohort_service_get_pools_associations.py <==
from typing import Any, Dict, List, Optional, Union

import httpx

from ...client import Client
from ...models.cohort_service_get_pools_associations_response_200 import (
    CohortService_GetPoolsAssociationsResponse_200,
)
from ...models.cohort_service_get_pools_associations_response_401 import (
    CohortService_GetPoolsAssociationsResponse_401,
)
from ...models.cohort_service_get_pools_associations_response_404 import (
    CohortService_GetPoolsAssociationsResponse_404,
)
from ...models.cohort_service_get_pools_associations_response_500 import (
    CohortService_GetPoolsAssociationsResponse_500,
)
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: Client,
    cusips: Union[Unset, List[str]] = UNSET,
    dateyear: Union[Unset, int] = UNSET,
    datemonth: Union[Unset, int] = UNSET,
    dateday: Union[Unset, int] = UNSET,
    month_back: Union[Unset, int] = UNSET,
) -> Dict[str, Any]:
    url = "{}/api/v1/cohorts/pools_associations".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()

    json_cusips: Union[Unset, List[Any]] = UNSET
    if not isinstance(cusips, Unset):
        json_cusips = cusips

    params: Dict[str, Any] = {
        "cusips": json_cusips,
        "date.year": dateyear,
        "date.month": datemonth,
        "date.day": dateday,
        "monthBack": month_back,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "url": url,
        "headers": headers,
        "cookies": client.get_cookies(),
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(
    *, response: httpx.Response
) -> Optional[
    Union[
        CohortService_GetPoolsAssociationsResponse_200,
        CohortService_GetPoolsAssociationsResponse_401,
        CohortService_GetPoolsAssociationsResponse_404,
        CohortService_GetPoolsAssociationsResponse_500,
    ]
]:
    if response.status_code == 200:
        response_200 = CohortService_GetPoolsAssociationsResponse_200.from_dict(
            response.json()
        )

        return response_200
    if response.status_code == 401:
        response_401 = CohortService_GetPoolsAssociationsResponse_401.from_dict(
            response.json()
        )

        return response_401
    if response.status_code == 404:
        response_404 = CohortService_GetPoolsAssociationsResponse_404.from_dict(
            response.json()
        )

        return response_404
    if response.status_code == 500:
        response_500 = CohortService_GetPoolsAssociationsResponse_500.from_dict(
            response.json()
        )

        return response_500
    return None


def _build_response(
    *, response: httpx.Response
) -> Response[
    Union[
        CohortService_GetPoolsAssociationsResponse_200,
        CohortService_GetPoolsAssociationsResponse_401,
        CohortService_GetPoolsAssociationsResponse_404,
        CohortService_GetPoolsAssociationsResponse_500,
    ]
]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
    cusips: Union[Unset, List[str]] = UNSET,
    dateyear: Union[Unset, int] = UNSET,
    datemonth: Union[Unset, int] = UNSET,
    dateday: Union[Unset, int] = UNSET,
    month_back: Union[Unset, int] = UNSET,
) -> Response[
    Union[
        CohortService_GetPoolsAssociationsResponse_200,
        CohortService_GetPoolsAssociationsResponse_401,
        CohortService_GetPoolsAssociationsResponse_404,
        CohortService_GetPoolsAssociationsResponse_500,
    ]
]:
    kwargs = _get_kwargs(
        client=client,
        cusips=cusips,
        dateyear=dateyear,
        datemonth=datemonth,
        dateday=dateday,
        month_back=month_back,
    )

    response = httpx.get(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
    cusips: Union[Unset, List[str]] = UNSET,
    dateyear: Union[Unset, int] = UNSET,
    datemonth: Union[Unset, int] = UNSET,
    dateday: Union[Unset, int] = UNSET,
    month_back: Union[Unset, int] = UNSET,
) -> Optional[
    Union[
        CohortService_GetPoolsAssociationsResponse_200,
        CohortService_GetPoolsAssociationsResponse_401,
        CohortService_GetPoolsAssociationsResponse_404,
        CohortService_GetPoolsAssociationsResponse_500,
    ]
]:
    """


    Args:
        cusips: None
        dateyear: Year of the date. Must be from 1 to 9999, or 0 to specify a date without a year
        datemonth: Month of a year. Must be from 1 to 12, or 0 to specify a year without a month and day.
        dateday: Day of a month. Must be from 1 to 31 and valid for the year and month, or 0 to specify a year by itself or a year and month where the day isn't significant.Month of a year. Must be from 1 to 12, or 0 to specify a year without a month and day.
        month_back: None

    Returns:
        Either a valid response or an unauthorized, not found or other error.
    """

    return sync_detailed(
        client=client,
        cusips=cusips,
        dateyear=dateyear,
        datemonth=datemonth,
        dateday=dateday,
        month_back=month_back,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
    cusips: Union[Unset, List[str]] = UNSET,
    dateyear: Union[Unset, int] = UNSET,
    datemonth: Union[Unset, int] = UNSET,
    dateday: Union[Unset, int] = UNSET,
    month_back: Union[Unset, int] = UNSET,
) -> Response[
    Union[
        CohortService_GetPoolsAssociationsResponse_200,
        CohortService_GetPoolsAssociationsResponse_401,
        CohortService_GetPoolsAssociationsResponse_404,
        CohortService_GetPoolsAssociationsResponse_500,
    ]
]:
    kwargs = _get_kwargs(
        client=client,
        cusips=cusips,
        dateyear=dateyear,
        datemonth=datemonth,
        dateday=dateday,
        month_back=month_back,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
    cusips: Union[Unset, List[str]] = UNSET,
    dateyear: Union[Unset, int] = UNSET,
    datemonth: Union[Unset, int] = UNSET,
    dateday: Union[Unset, int] = UNSET,
    month_back: Union[Unset, int] = UNSET,
) -> Optional[
    Union[
        CohortService_GetPoolsAssociationsResponse_200,
        CohortService_GetPoolsAssociationsResponse_401,
        CohortService_GetPoolsAssociationsResponse_404,
        CohortService_GetPoolsAssociationsResponse_500,
    ]
]:
    """  """

    return (
        await asyncio_detailed(
            client=client,
            cusips=cusips,
            dateyear=dateyear,
            datemonth=datemonth,
            dateday=dateday,
            month_back=month_back,
        )
    ).parsed

==> infima_client-0.259.0-py3-none-any.whl: infima_client/api/cohort_service/cohort_service_get_pools_associations.py <==
from typing import Any, Dict, List, Optional, Union

import httpx

from ...client import Client
from ...models.pools_associations import PoolsAssociations
from ...models.pools_associations_error import PoolsAssociationsError
from ...models.pools_associations_not_found import PoolsAssociationsNotFound
from ...models.pools_associations_unauthorized import PoolsAssociationsUnauthorized
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: Client,
    cusips: Union[Unset, List[str]] = UNSET,
    dateyear: Union[Unset, int] = UNSET,
    datemonth: Union[Unset, int] = UNSET,
    dateday: Union[Unset, int] = UNSET,
    month_back: Union[Unset, int] = UNSET,
) -> Dict[str, Any]:
    url = "{}/api/v1/cohorts/pools_associations".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()

    json_cusips: Union[Unset, List[Any]] = UNSET
    if not isinstance(cusips, Unset):
        json_cusips = cusips

    params: Dict[str, Any] = {
        "cusips": json_cusips,
        "date.year": dateyear,
        "date.month": datemonth,
        "date.day": dateday,
        "monthBack": month_back,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "url": url,
        "headers": headers,
        "cookies": client.get_cookies(),
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(
    *, response: httpx.Response
) -> Optional[
    Union[
        PoolsAssociations,
        PoolsAssociationsUnauthorized,
        PoolsAssociationsNotFound,
        PoolsAssociationsError,
    ]
]:
    if response.status_code == 200:
        response_200 = PoolsAssociations.from_dict(response.json())

        return response_200
    if response.status_code == 401:
        response_401 = PoolsAssociationsUnauthorized.from_dict(response.json())

        return response_401
    if response.status_code == 404:
        response_404 = PoolsAssociationsNotFound.from_dict(response.json())

        return response_404
    if response.status_code == 500:
        response_500 = PoolsAssociationsError.from_dict(response.json())

        return response_500
    return None


def _build_response(
    *, response: httpx.Response
) -> Response[
    Union[
        PoolsAssociations,
        PoolsAssociationsUnauthorized,
        PoolsAssociationsNotFound,
        PoolsAssociationsError,
    ]
]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
    cusips: Union[Unset, List[str]] = UNSET,
    dateyear: Union[Unset, int] = UNSET,
    datemonth: Union[Unset, int] = UNSET,
    dateday: Union[Unset, int] = UNSET,
    month_back: Union[Unset, int] = UNSET,
) -> Response[
    Union[
        PoolsAssociations,
        PoolsAssociationsUnauthorized,
        PoolsAssociationsNotFound,
        PoolsAssociationsError,
    ]
]:
    kwargs = _get_kwargs(
        client=client,
        cusips=cusips,
        dateyear=dateyear,
        datemonth=datemonth,
        dateday=dateday,
        month_back=month_back,
    )

    response = httpx.get(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
    cusips: Union[Unset, List[str]] = UNSET,
    dateyear: Union[Unset, int] = UNSET,
    datemonth: Union[Unset, int] = UNSET,
    dateday: Union[Unset, int] = UNSET,
    month_back: Union[Unset, int] = UNSET,
) -> Optional[
    Union[
        PoolsAssociations,
        PoolsAssociationsUnauthorized,
        PoolsAssociationsNotFound,
        PoolsAssociationsError,
    ]
]:
    """


    Args:
        cusips: None
        dateyear: Year of the date. Must be from 1 to 9999, or 0 to specify a date without a year
        datemonth: Month of a year. Must be from 1 to 12, or 0 to specify a year without a month and day.
        dateday: Day of a month. Must be from 1 to 31 and valid for the year and month, or 0 to specify a year by itself or a year and month where the day isn't significant.Month of a year. Must be from 1 to 12, or 0 to specify a year without a month and day.
        month_back: None

    Returns:
        Either a valid response or an unauthorized, not found or other error.
    """

    return sync_detailed(
        client=client,
        cusips=cusips,
        dateyear=dateyear,
        datemonth=datemonth,
        dateday=dateday,
        month_back=month_back,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
    cusips: Union[Unset, List[str]] = UNSET,
    dateyear: Union[Unset, int] = UNSET,
    datemonth: Union[Unset, int] = UNSET,
    dateday: Union[Unset, int] = UNSET,
    month_back: Union[Unset, int] = UNSET,
) -> Response[
    Union[
        PoolsAssociations,
        PoolsAssociationsUnauthorized,
        PoolsAssociationsNotFound,
        PoolsAssociationsError,
    ]
]:
    kwargs = _get_kwargs(
        client=client,
        cusips=cusips,
        dateyear=dateyear,
        datemonth=datemonth,
        dateday=dateday,
        month_back=month_back,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
    cusips: Union[Unset, List[str]] = UNSET,
    dateyear: Union[Unset, int] = UNSET,
    datemonth: Union[Unset, int] = UNSET,
    dateday: Union[Unset, int] = UNSET,
    month_back: Union[Unset, int] = UNSET,
) -> Optional[
    Union[
        PoolsAssociations,
        PoolsAssociationsUnauthorized,
        PoolsAssociationsNotFound,
        PoolsAssociationsError,
    ]
]:
    """  """

    return (
        await asyncio_detailed(
            client=client,
            cusips=cusips,
            dateyear=dateyear,
            datemonth=datemonth,
            dateday=dateday,
            month_back=month_back,
        )
    ).parsed
